Struct Cier
#[repr(transparent)]pub struct Cier(pub u32);Expand description
CIER register.
Tuple Fields
0: u32Implementations
impl Cier
impl Cier
pub const fn lsirdyie(&self) -> bool
pub const fn lsirdyie(&self) -> bool
LSI Ready Interrupt Enable. Set and reset by software to enable/disable interrupt caused by internal RC 32 kHz oscillator stabilization.
pub fn set_lsirdyie(&mut self, val: bool)
pub fn set_lsirdyie(&mut self, val: bool)
LSI Ready Interrupt Enable. Set and reset by software to enable/disable interrupt caused by internal RC 32 kHz oscillator stabilization.
pub const fn lserdyie(&self) -> bool
pub const fn lserdyie(&self) -> bool
LSE Ready Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the external 32 kHz oscillator stabilization.
pub fn set_lserdyie(&mut self, val: bool)
pub fn set_lserdyie(&mut self, val: bool)
LSE Ready Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the external 32 kHz oscillator stabilization.
pub const fn hsirdyie(&self) -> bool
pub const fn hsirdyie(&self) -> bool
HSI Ready Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the internal RC 64MHz oscillator stabilization.
pub fn set_hsirdyie(&mut self, val: bool)
pub fn set_hsirdyie(&mut self, val: bool)
HSI Ready Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the internal RC 64MHz oscillator stabilization.
pub const fn hserdyie(&self) -> bool
pub const fn hserdyie(&self) -> bool
HSE Ready Interrupt Enable Set and reset by software to enable/disable interrupt caused by the external HSE oscillator stabilization.
pub fn set_hserdyie(&mut self, val: bool)
pub fn set_hserdyie(&mut self, val: bool)
HSE Ready Interrupt Enable Set and reset by software to enable/disable interrupt caused by the external HSE oscillator stabilization.
pub const fn hsipllrdyie(&self) -> bool
pub const fn hsipllrdyie(&self) -> bool
HSI PLL Ready Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the HSI 64MHz PLL locked on HSE.
pub fn set_hsipllrdyie(&mut self, val: bool)
pub fn set_hsipllrdyie(&mut self, val: bool)
HSI PLL Ready Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the HSI 64MHz PLL locked on HSE.
pub const fn hsipllunlockdetie(&self) -> bool
pub const fn hsipllunlockdetie(&self) -> bool
HSIPLLUNLOCKDETIE: HSI PLL unlock detection Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the HSI 64MHz PLL unlock.
pub fn set_hsipllunlockdetie(&mut self, val: bool)
pub fn set_hsipllunlockdetie(&mut self, val: bool)
HSIPLLUNLOCKDETIE: HSI PLL unlock detection Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the HSI 64MHz PLL unlock.
pub const fn rtcrstie(&self) -> bool
pub const fn rtcrstie(&self) -> bool
RTCRSTIE: RTC reset end Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the RTC reset end.
pub fn set_rtcrstie(&mut self, val: bool)
pub fn set_rtcrstie(&mut self, val: bool)
RTCRSTIE: RTC reset end Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the RTC reset end.
pub const fn wdgrstie(&self) -> bool
pub const fn wdgrstie(&self) -> bool
WDGRSTIE: Watchdog reset end Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the watchdog reset end.
pub fn set_wdgrstie(&mut self, val: bool)
pub fn set_wdgrstie(&mut self, val: bool)
WDGRSTIE: Watchdog reset end Interrupt Enable. Set and reset by software to enable/disable interrupt caused by the watchdog reset end.
pub fn set_lpurstie(&mut self, val: bool)
pub fn set_lpurstie(&mut self, val: bool)
LPURSTIE: LPUART reset release interrupt enable.